package org.jeecg.modules.teambuyLevel.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.teambuyLevel.entity.TeambuyLevel;
import org.jeecg.modules.teambuyLevel.service.ITeambuyLevelService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 佣金等级表
 * @Author: jeecg-boot
 * @Date:   2025-05-08
 * @Version: V1.0
 */
@Api(tags="佣金等级表")
@RestController
@RequestMapping("/teambuyLevel/teambuyLevel")
@Slf4j
public class TeambuyLevelController extends JeecgController<TeambuyLevel, ITeambuyLevelService> {
	@Autowired
	private ITeambuyLevelService teambuyLevelService;
	
	/**
	 * 分页列表查询
	 *
	 * @param teambuyLevel
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "佣金等级表-分页列表查询")
	@ApiOperation(value="佣金等级表-分页列表查询", notes="佣金等级表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<TeambuyLevel>> queryPageList(TeambuyLevel teambuyLevel,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<TeambuyLevel> queryWrapper = QueryGenerator.initQueryWrapper(teambuyLevel, req.getParameterMap());
		Page<TeambuyLevel> page = new Page<TeambuyLevel>(pageNo, pageSize);
		IPage<TeambuyLevel> pageList = teambuyLevelService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param teambuyLevel
	 * @return
	 */
	@AutoLog(value = "佣金等级表-添加")
	@ApiOperation(value="佣金等级表-添加", notes="佣金等级表-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody TeambuyLevel teambuyLevel) {
		teambuyLevelService.save(teambuyLevel);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param teambuyLevel
	 * @return
	 */
	@AutoLog(value = "佣金等级表-编辑")
	@ApiOperation(value="佣金等级表-编辑", notes="佣金等级表-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody TeambuyLevel teambuyLevel) {
		teambuyLevelService.updateById(teambuyLevel);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "佣金等级表-通过id删除")
	@ApiOperation(value="佣金等级表-通过id删除", notes="佣金等级表-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		teambuyLevelService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "佣金等级表-批量删除")
	@ApiOperation(value="佣金等级表-批量删除", notes="佣金等级表-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.teambuyLevelService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "佣金等级表-通过id查询")
	@ApiOperation(value="佣金等级表-通过id查询", notes="佣金等级表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<TeambuyLevel> queryById(@RequestParam(name="id",required=true) String id) {
		TeambuyLevel teambuyLevel = teambuyLevelService.getById(id);
		if(teambuyLevel==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(teambuyLevel);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param teambuyLevel
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, TeambuyLevel teambuyLevel) {
        return super.exportXls(request, teambuyLevel, TeambuyLevel.class, "佣金等级表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, TeambuyLevel.class);
    }

}
