package org.jeecg.modules.teambuyOrderLeader.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.teambuyOrderLeader.entity.TeambuyOrderLeader;
import org.jeecg.modules.teambuyOrderLeader.service.ITeambuyOrderLeaderService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 团长团餐订单表
 * @Author: jeecg-boot
 * @Date:   2025-05-26
 * @Version: V1.0
 */
@Api(tags="团长团餐订单表")
@RestController
@RequestMapping("/teambuyOrderLeader/teambuyOrderLeader")
@Slf4j
public class TeambuyOrderLeaderController extends JeecgController<TeambuyOrderLeader, ITeambuyOrderLeaderService> {
	@Autowired
	private ITeambuyOrderLeaderService teambuyOrderLeaderService;
	
	/**
	 * 分页列表查询
	 *
	 * @param teambuyOrderLeader
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "团长团餐订单表-分页列表查询")
	@ApiOperation(value="团长团餐订单表-分页列表查询", notes="团长团餐订单表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<TeambuyOrderLeader>> queryPageList(TeambuyOrderLeader teambuyOrderLeader,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<TeambuyOrderLeader> queryWrapper = QueryGenerator.initQueryWrapper(teambuyOrderLeader, req.getParameterMap());
		Page<TeambuyOrderLeader> page = new Page<TeambuyOrderLeader>(pageNo, pageSize);
		IPage<TeambuyOrderLeader> pageList = teambuyOrderLeaderService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param teambuyOrderLeader
	 * @return
	 */
	@AutoLog(value = "团长团餐订单表-添加")
	@ApiOperation(value="团长团餐订单表-添加", notes="团长团餐订单表-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody TeambuyOrderLeader teambuyOrderLeader) {
		teambuyOrderLeaderService.save(teambuyOrderLeader);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param teambuyOrderLeader
	 * @return
	 */
	@AutoLog(value = "团长团餐订单表-编辑")
	@ApiOperation(value="团长团餐订单表-编辑", notes="团长团餐订单表-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody TeambuyOrderLeader teambuyOrderLeader) {
		teambuyOrderLeaderService.updateById(teambuyOrderLeader);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "团长团餐订单表-通过id删除")
	@ApiOperation(value="团长团餐订单表-通过id删除", notes="团长团餐订单表-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		teambuyOrderLeaderService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "团长团餐订单表-批量删除")
	@ApiOperation(value="团长团餐订单表-批量删除", notes="团长团餐订单表-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.teambuyOrderLeaderService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "团长团餐订单表-通过id查询")
	@ApiOperation(value="团长团餐订单表-通过id查询", notes="团长团餐订单表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<TeambuyOrderLeader> queryById(@RequestParam(name="id",required=true) String id) {
		TeambuyOrderLeader teambuyOrderLeader = teambuyOrderLeaderService.getById(id);
		if(teambuyOrderLeader==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(teambuyOrderLeader);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param teambuyOrderLeader
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, TeambuyOrderLeader teambuyOrderLeader) {
        return super.exportXls(request, teambuyOrderLeader, TeambuyOrderLeader.class, "团长团餐订单表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, TeambuyOrderLeader.class);
    }

}
